@@ -31,6 +31,7 @@ class BaseHandler(RequestHandler):
         :param request:
         :param kwargs:
         """
+        self.original = False
         super().__init__(application, request, **kwargs)
 
     async def get(self):
@@ -91,7 +92,8 @@ class BaseHandler(RequestHandler):
             else:
                 # 阻塞方法异步调用
                 data = await IOLoop.current().run_in_executor(None, handler_method, *params_list)
-            self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
+            if not self.original:
+                self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
         else:
             raise BusinessException(StatusCode.RESOURCE_NOT_FOUND)
 
@@ -177,7 +179,8 @@ class BaseHandler(RequestHandler):
             else:
                 # 阻塞方法异步调用
                 data = await IOLoop.current().run_in_executor(None, handler_method, *params_list)
-            self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
+            if not self.original:
+                self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
         else:
             raise BusinessException(StatusCode.RESOURCE_NOT_FOUND)
 
